@@ -1,3 +1,4 @@
+import django
 from django.contrib import messages
 from django.contrib.auth import get_user_model
 from django.core.exceptions import PermissionDenied
@@ -36,22 +37,21 @@ def multifactor_protected(factors=0, user_filter=None, max_age=0, advertise=Fals
     def _func_wrapper(view_func, *args, **kwargs):
         @functools.wraps(view_func)
         def _wrapped_view_func(request, *args, **kwargs):
-            def baulk():
-                return view_func(request, *args, **kwargs)
-
             def force_authenticate():
-                if request.is_ajax():
+                if not request.META.get('HTTP_ACCEPT', '').startswith('text/html'):
+                    # Assume that this is a ajax/fetch/non-standard request
                     raise PermissionDenied('Multifactor authentication required')
+
                 request.session['multifactor-next'] = request.get_full_path()
                 return redirect('multifactor:authenticate')
 
             if not request.user.is_authenticated:
-                return baulk()
+                return view_func(request, *args, **kwargs)
 
             if user_filter is not None:
                 # we're filtering for specific users, check that the current user fits that
                 if not get_user_model().objects.filter(pk=request.user.pk, **user_filter).exists():
-                    return baulk()
+                    return view_func(request, *args, **kwargs)
 
             active = active_factors(request)
 
@@ -91,6 +91,6 @@ def multifactor_protected(factors=0, user_filter=None, max_age=0, advertise=Fals
                 ))
                 request.session['multifactor-advertised'] = True
 
-            return baulk()
+            return view_func(request, *args, **kwargs)
         return _wrapped_view_func
     return _func_wrapper
